@@ -14,7 +14,7 @@ sub can_handle {
     # I think there's a TAP::Parser bug thinking the first line of .t
     # file as a shebang even if it doesn't begin with '#!'
     local $src->meta->{file}{shebang} = undef
-      if $src->meta->{file}{shebang} !~ /^\#\!/;
+      if $src->meta->{file}{shebang} !~ /^#!/;
 
     my $is_perl = TAP::Parser::SourceHandler::Perl->can_handle($src);
     return 1 if $is_perl > 0.5 && !$class->ignore($src->meta->{file});
@@ -73,12 +73,8 @@ sub _run {
         $Test::Builder::Test->reset;
     }
 
-    # Eliminated blacklisted modules from %INC so that child can reload on demand
-    for my $package (@App::ForkProve::Captured) {
-        no strict 'refs';
-        undef %{"$package\::"};
-        delete $INC{ App::ForkProve::pkg_to_file($package) };
-    }
+    # avoid child processes sharing the same seed value as the parent
+    srand();
 
     # do() can't tell if a test can't be read or a .t's last statement
     # returned undef with $! set somewhere. Fortunately in case of
